@@ -21,6 +21,8 @@ from ormar.fields.model_fields import (
     Time,
     UUID,
 )
+from ormar.fields.parsers import DECODERS_MAP, ENCODERS_MAP
+from ormar.fields.sqlalchemy_encrypted import EncryptBackend, EncryptBackends
 from ormar.fields.through_field import Through, ThroughField
 
 __all__ = [
@@ -44,4 +46,8 @@ __all__ = [
     "ForeignKeyField",
     "ThroughField",
     "Through",
+    "EncryptBackends",
+    "EncryptBackend",
+    "DECODERS_MAP",
+    "ENCODERS_MAP",
 ]
