@@ -54,6 +54,14 @@ class BaseField(FieldInfo):
         )  # ForeignKeyField + subclasses
         self.is_through: bool = kwargs.pop("is_through", False)  # ThroughFields
 
+        self.through_relation_name = kwargs.pop("through_relation_name", None)
+        self.through_reverse_relation_name = kwargs.pop(
+            "through_reverse_relation_name", None
+        )
+
+        self.skip_reverse: bool = kwargs.pop("skip_reverse", False)
+        self.skip_field: bool = kwargs.pop("skip_field", False)
+
         self.owner: Type["Model"] = kwargs.pop("owner", None)
         self.to: Type["Model"] = kwargs.pop("to", None)
         self.through: Type["Model"] = kwargs.pop("through", None)
