@@ -233,9 +233,13 @@ def ForeignKey(  # noqa CFQ002
 
     owner = kwargs.pop("owner", None)
     self_reference = kwargs.pop("self_reference", False)
+
     orders_by = kwargs.pop("orders_by", None)
     related_orders_by = kwargs.pop("related_orders_by", None)
 
+    skip_reverse = kwargs.pop("skip_reverse", False)
+    skip_field = kwargs.pop("skip_field", False)
+
     validate_not_allowed_fields(kwargs)
 
     if to.__class__ == ForwardRef:
@@ -274,6 +278,8 @@ def ForeignKey(  # noqa CFQ002
         is_relation=True,
         orders_by=orders_by,
         related_orders_by=related_orders_by,
+        skip_reverse=skip_reverse,
+        skip_field=skip_field,
     )
 
     Field = type("ForeignKey", (ForeignKeyField, BaseField), {})
@@ -312,6 +318,24 @@ class ForeignKeyField(BaseField):
         """
         return self.related_name or self.owner.get_name() + "s"
 
+    def default_target_field_name(self) -> str:
+        """
+        Returns default target model name on through model.
+        :return: name of the field
+        :rtype: str
+        """
+        prefix = "from_" if self.self_reference else ""
+        return self.through_reverse_relation_name or f"{prefix}{self.to.get_name()}"
+
+    def default_source_field_name(self) -> str:
+        """
+        Returns default target model name on through model.
+        :return: name of the field
+        :rtype: str
+        """
+        prefix = "to_" if self.self_reference else ""
+        return self.through_relation_name or f"{prefix}{self.owner.get_name()}"
+
     def evaluate_forward_ref(self, globalns: Any, localns: Any) -> None:
         """
         Evaluates the ForwardRef to actual Field based on global and local namespaces
