@@ -697,7 +697,7 @@ class NewBaseModel(pydantic.BaseModel, ModelTableProxy, metaclass=ModelMetaclass
             if relation_map is not None
             else translate_list_to_dict(self._iterate_related_models())
         )
-        pk_only = object.__getattribute__(self, "__pk_only__")
+        pk_only = getattr(self, "__pk_only__", False)
         if relation_map and not pk_only:
             dict_instance = self._extract_nested_models(
                 relation_map=relation_map,
